#[non_exhaustive]pub enum IpcAddr<P, A> {
Unix(UnixAddr<P>),
Abstract(AbstractAddr<A>),
Vsock(VsockAddr),
}Expand description
A non-IP communication address.
Path-backed transports use P, and byte-backed transports use A. The
type intentionally does not contain HostAddr or core::net::SocketAddr.
Enum variants store their payloads by value, so DST storage is represented
through sized references such as IpcAddr<&Path, &[u8]>.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unix(UnixAddr<P>)
Available on Unix only.
A Unix-domain socket pathname.
Abstract(AbstractAddr<A>)
Available on Linux only.
A Linux abstract socket name, without the leading NUL byte.
Vsock(VsockAddr)
Available on Linux and crate feature
vsock only.A VM socket address.